@@ -17,29 +17,30 @@
 
 // Note this include is placed in the src file because
 // otherwise ogre produces compile errors
-#ifdef _MSC_VER
-#pragma warning(push, 0)
+#if defined(_MSC_VER)
+#pragma warning(push)
+#pragma warning(disable: 5033)
 #endif
 #include <Hlms/Pbs/OgreHlmsPbsDatablock.h>
-#ifdef _MSC_VER
+#if defined(_MSC_VER)
 #pragma warning(pop)
 #endif
 
-#include "ignition/common/Console.hh"
-#include "ignition/rendering/ogre2/Ogre2Conversions.hh"
-#include "ignition/rendering/ogre2/Ogre2DynamicRenderable.hh"
-#include "ignition/rendering/ogre2/Ogre2Material.hh"
-#include "ignition/rendering/ogre2/Ogre2RenderEngine.hh"
-#include "ignition/rendering/ogre2/Ogre2Scene.hh"
+#include "gz/common/Console.hh"
+#include "gz/rendering/ogre2/Ogre2Conversions.hh"
+#include "gz/rendering/ogre2/Ogre2DynamicRenderable.hh"
+#include "gz/rendering/ogre2/Ogre2Material.hh"
+#include "gz/rendering/ogre2/Ogre2RenderEngine.hh"
+#include "gz/rendering/ogre2/Ogre2Scene.hh"
 
 /// \brief Private implementation
-class ignition::rendering::Ogre2DynamicRenderablePrivate
+class gz::rendering::Ogre2DynamicRenderablePrivate
 {
   /// \brief list of colors at each point
-  public: std::vector<ignition::math::Color> colors;
+  public: std::vector<gz::math::Color> colors;
 
   /// \brief List of vertices for the mesh
-  public: std::vector<ignition::math::Vector3d> vertices;
+  public: std::vector<gz::math::Vector3d> vertices;
 
   /// \brief Used to indicate if the lines require an update
   public: bool dirty = false;
@@ -80,7 +81,7 @@ class ignition::rendering::Ogre2DynamicRenderablePrivate
 };
 
 
-using namespace ignition;
+using namespace gz;
 using namespace rendering;
 
 //////////////////////////////////////////////////
@@ -404,8 +405,8 @@ MarkerType Ogre2DynamicRenderable::OperationType() const
 }
 
 /////////////////////////////////////////////////
-void Ogre2DynamicRenderable::AddPoint(const ignition::math::Vector3d &_pt,
-                                      const ignition::math::Color &_color)
+void Ogre2DynamicRenderable::AddPoint(const math::Vector3d &_pt,
+                                      const math::Color &_color)
 {
   this->dataPtr->vertices.push_back(_pt);
 
@@ -420,14 +421,14 @@ void Ogre2DynamicRenderable::AddPoint(const ignition::math::Vector3d &_pt,
 
 /////////////////////////////////////////////////
 void Ogre2DynamicRenderable::AddPoint(double _x, double _y, double _z,
-                                      const ignition::math::Color &_color)
+                                      const math::Color &_color)
 {
-  this->AddPoint(ignition::math::Vector3d(_x, _y, _z), _color);
+  this->AddPoint(math::Vector3d(_x, _y, _z), _color);
 }
 
 /////////////////////////////////////////////////
 void Ogre2DynamicRenderable::SetPoint(unsigned int _index,
-                                      const ignition::math::Vector3d &_value)
+                                      const math::Vector3d &_value)
 {
   if (_index >= this->dataPtr->vertices.size())
   {
@@ -443,7 +444,7 @@ void Ogre2DynamicRenderable::SetPoint(unsigned int _index,
 
 /////////////////////////////////////////////////
 void Ogre2DynamicRenderable::SetColor(unsigned int _index,
-                                      const ignition::math::Color &_color)
+                                      const math::Color &_color)
 {
   if (_index >= this->dataPtr->colors.size())
   {
@@ -463,7 +464,7 @@ void Ogre2DynamicRenderable::SetColor(unsigned int _index,
 }
 
 /////////////////////////////////////////////////
-ignition::math::Vector3d Ogre2DynamicRenderable::Point(
+math::Vector3d Ogre2DynamicRenderable::Point(
     const unsigned int _index) const
 {
   if (_index >= this->dataPtr->vertices.size())
@@ -471,9 +472,9 @@ ignition::math::Vector3d Ogre2DynamicRenderable::Point(
     ignerr << "Point index[" << _index << "] is out of bounds[0-"
            << this->dataPtr->vertices.size()-1 << "]\n";
 
-    return ignition::math::Vector3d(ignition::math::INF_D,
-                                    ignition::math::INF_D,
-                                    ignition::math::INF_D);
+    return math::Vector3d(math::INF_D,
+                                    math::INF_D,
+                                    math::INF_D);
   }
 
   return this->dataPtr->vertices[_index];
