@@ -14,10 +14,10 @@
  * limitations under the License.
  *
  */
-#include "ignition/rendering/ogre2/Ogre2RenderPass.hh"
+#include "gz/rendering/ogre2/Ogre2RenderPass.hh"
 
 
-using namespace ignition;
+using namespace gz;
 using namespace rendering;
 
 //////////////////////////////////////////////////
