@@ -15,13 +15,13 @@
  *
  */
 
-#include "ignition/rendering/RenderEnginePlugin.hh"
+#include "gz/rendering/RenderEnginePlugin.hh"
 
-class ignition::rendering::RenderEnginePluginPrivate
+class gz::rendering::RenderEnginePluginPrivate
 {
 };
 
-using namespace ignition;
+using namespace gz;
 using namespace rendering;
 
 //////////////////////////////////////////////////
