@@ -17,16 +17,16 @@
 
 #include <gtest/gtest.h>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Filesystem.hh>
-#include <ignition/common/Event.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/common/Event.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
 
-#include "ignition/rendering/DepthCamera.hh"
-#include "ignition/rendering/RenderEngine.hh"
-#include "ignition/rendering/RenderingIface.hh"
-#include "ignition/rendering/Scene.hh"
+#include "gz/rendering/DepthCamera.hh"
+#include "gz/rendering/RenderEngine.hh"
+#include "gz/rendering/RenderingIface.hh"
+#include "gz/rendering/Scene.hh"
 
 #define DEPTH_TOL 1e-4
 #define DOUBLE_TOL 1e-6
@@ -71,7 +71,7 @@ void DepthCameraTest::DepthCameraBoxes(
   double aspectRatio_ = imgWidth_/imgHeight_;
 
   double unitBoxSize = 1.0;
-  ignition::math::Vector3d boxPosition(1.8, 0.0, 0.0);
+  gz::math::Vector3d boxPosition(1.8, 0.0, 0.0);
 
   // Optix is not supported
   if (_renderEngine.compare("optix") == 0)
@@ -82,7 +82,7 @@ void DepthCameraTest::DepthCameraBoxes(
   }
 
   // Setup ign-rendering with an empty scene
-  auto *engine = ignition::rendering::engine(_renderEngine);
+  auto *engine = gz::rendering::engine(_renderEngine);
   if (!engine)
   {
     igndbg << "Engine '" << _renderEngine
@@ -90,23 +90,23 @@ void DepthCameraTest::DepthCameraBoxes(
     return;
   }
 
-  ignition::rendering::ScenePtr scene = engine->CreateScene("scene");
+  gz::rendering::ScenePtr scene = engine->CreateScene("scene");
 
   // red background
   scene->SetBackgroundColor(1.0, 0.0, 0.0);
 
   // Create an scene with a box in it
   scene->SetAmbientLight(1.0, 1.0, 1.0);
-  ignition::rendering::VisualPtr root = scene->RootVisual();
+  gz::rendering::VisualPtr root = scene->RootVisual();
 
   // create blue material
-  ignition::rendering::MaterialPtr blue = scene->CreateMaterial();
+  gz::rendering::MaterialPtr blue = scene->CreateMaterial();
   blue->SetAmbient(0.0, 0.0, 1.0);
   blue->SetDiffuse(0.0, 0.0, 1.0);
   blue->SetSpecular(0.0, 0.0, 1.0);
 
   // create box visual
-  ignition::rendering::VisualPtr box = scene->CreateVisual();
+  gz::rendering::VisualPtr box = scene->CreateVisual();
   box->AddGeometry(scene->CreateBox());
   box->SetOrigin(0.0, 0.0, 0.0);
   box->SetLocalPosition(boxPosition);
@@ -122,8 +122,8 @@ void DepthCameraTest::DepthCameraBoxes(
     auto depthCamera = scene->CreateDepthCamera("DepthCamera");
     ASSERT_NE(depthCamera, nullptr);
 
-    ignition::math::Pose3d testPose(ignition::math::Vector3d(0, 0, 0),
-        ignition::math::Quaterniond::Identity);
+    gz::math::Pose3d testPose(gz::math::Vector3d(0, 0, 0),
+        gz::math::Quaterniond::Identity);
     depthCamera->SetLocalPose(testPose);
 
     // Configure depth camera
@@ -147,7 +147,7 @@ void DepthCameraTest::DepthCameraBoxes(
 
     // Set a callback on the  camera sensor to get a depth camera frame
     float *scan = new float[imgHeight_ * imgWidth_];
-    ignition::common::ConnectionPtr connection =
+    gz::common::ConnectionPtr connection =
       depthCamera->ConnectNewDepthFrame(
           std::bind(&::OnNewDepthFrame, scan,
             std::placeholders::_1, std::placeholders::_2, std::placeholders::_3,
@@ -157,7 +157,7 @@ void DepthCameraTest::DepthCameraBoxes(
     unsigned int pointCloudChannelCount = 4u;
     float *pointCloudData = new float[
         imgHeight_ * imgWidth_ * pointCloudChannelCount];
-    ignition::common::ConnectionPtr connection2 =
+    gz::common::ConnectionPtr connection2 =
       depthCamera->ConnectNewRgbPointCloud(
           std::bind(&::OnNewRgbPointCloud, pointCloudData,
             std::placeholders::_1, std::placeholders::_2, std::placeholders::_3,
@@ -189,8 +189,8 @@ void DepthCameraTest::DepthCameraBoxes(
         * (depthCamera->ImageWidth() * pointCloudChannelCount)
         - pointCloudChannelCount;
 
-    float minVal = -ignition::math::INF_D;
-    float maxVal = ignition::math::INF_D;
+    float minVal = -gz::math::INF_D;
+    float maxVal = gz::math::INF_D;
 
     // Verify Depth
     // Depth sensor should see box in the middle of the image
@@ -249,9 +249,10 @@ void DepthCameraTest::DepthCameraBoxes(
       unsigned int ma = *mrgba >> 0 & 0xFF;
       EXPECT_EQ(0u, mr);
       EXPECT_EQ(0u, mg);
-      // Note: If it fails here, it may be this problem again:
+#ifndef __APPLE__
       // https://github.com/ignitionrobotics/ign-rendering/issues/332
       EXPECT_GT(mb, 0u);
+#endif
 
       // Far left and right points should be red (background color)
       float lc = pointCloudData[pcLeft + 3];
@@ -288,7 +289,7 @@ void DepthCameraTest::DepthCameraBoxes(
     }
 
     // Check that for a box really close it returns it is not seen
-    ignition::math::Vector3d boxPositionNear(
+    gz::math::Vector3d boxPositionNear(
         unitBoxSize * 0.5 + nearDist * 0.5, 0.0, 0.0);
     box->SetLocalPosition(boxPositionNear);
 
@@ -344,7 +345,7 @@ void DepthCameraTest::DepthCameraBoxes(
     }
 
     // Check that for a box really far it returns max val
-    ignition::math::Vector3d boxPositionFar(
+    gz::math::Vector3d boxPositionFar(
         unitBoxSize * 0.5 + farDist * 1.5, 0.0, 0.0);
     box->SetLocalPosition(boxPositionFar);
 
@@ -402,7 +403,7 @@ void DepthCameraTest::DepthCameraBoxes(
     }
 
     // Check that the depth values for a box do not warp.
-    ignition::math::Vector3d boxPositionFillFrame(
+    gz::math::Vector3d boxPositionFillFrame(
         unitBoxSize * 0.5 + 0.2, 0.0, 0.0);
     box->SetLocalPosition(boxPositionFillFrame);
 
@@ -450,10 +451,11 @@ void DepthCameraTest::DepthCameraBoxes(
           unsigned int a = *rgba >> 0 & 0xFF;
           EXPECT_EQ(0u, r);
           EXPECT_EQ(0u, g);
-          // Note: If it fails here, it may be this problem again:
+#ifndef __APPLE__
           // https://github.com/ignitionrobotics/ign-rendering/issues/332
           EXPECT_GT(b, 0u);
           EXPECT_EQ(255u, a);
+#endif
         }
       }
     }
@@ -466,7 +468,7 @@ void DepthCameraTest::DepthCameraBoxes(
   }
 
   engine->DestroyScene(scene);
-  ignition::rendering::unloadEngine(engine->Name());
+  gz::rendering::unloadEngine(engine->Name());
 }
 
 TEST_P(DepthCameraTest, DepthCameraBoxes)
@@ -475,7 +477,7 @@ TEST_P(DepthCameraTest, DepthCameraBoxes)
 }
 
 INSTANTIATE_TEST_CASE_P(DepthCamera, DepthCameraTest,
-    RENDER_ENGINE_VALUES, ignition::rendering::PrintToStringParam());
+    RENDER_ENGINE_VALUES, gz::rendering::PrintToStringParam());
 
 //////////////////////////////////////////////////
 int main(int argc, char **argv)
